#
# spec file for package nodejs-common
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


###########################################################
#
#   WARNING! WARNING! WARNING! WARNING! WARNING! WARNING!
#
# This spec file is generated from a template hosted at
# https://github.com/AdamMajer/nodejs-packaging
#
###########################################################

%define NODEJS_CURRENT  22
%define NODEJS_LTS      22

%if 0%{?suse_version} > 1500 || 0%{?fedora_version}
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif

# SLE-12 variants
%if 0%{?suse_version} < 1500
%define default_node_ver 16
%endif

%if 0%{?suse_version} == 1500

# SLE-15 variants, variation based on SP
%if 0%{?sle_version} >= 150000 && 0%{?sle_version} < 150200
%define default_node_ver 10
%endif

%if 0%{?sle_version} >= 150200 && 0%{?sle_version} < 150300
%define default_node_ver 12
%endif

%if 0%{?sle_version} >= 150300 && 0%{?sle_version} < 150400
%define default_node_ver 14
%endif

%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 150500
%define default_node_ver 16
%endif

%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 150600
%define default_node_ver 18
%endif

%if 0%{?sle_version} >= 150600 && 0%{?sle_version} < 150700
%define default_node_ver 20
%endif

%if 0%{?sle_version} >= 150700
%define default_node_ver 22
%endif

# SLE-15 variants
%endif

%if 0%{?suse_version} == 1600
# SLFO variants
%define default_node_ver %NODEJS_LTS
%endif

# TW
%if 0%{?suse_version} >= 1699
%define default_node_ver %NODEJS_CURRENT
%endif

Name:           nodejs-common
Version:        6.1
Release:        3.5
Summary:        Common files for the NodeJS ecosystem
License:        MIT
Group:          Development/Languages/NodeJS
URL:            https://github.com/AdamMajer/nodejs-packaging
Source1:        node.c
Source2:        LICENSE
Requires:       nodejs
Conflicts:      nodejs4 < 4.8.4
Conflicts:      nodejs6 < 6.11.1
Conflicts:      nodejs7 < 7.10.1
Conflicts:      nodejs8 < 8.1.4
BuildRequires:  gcc
%if %{with libalternatives}
BuildRequires:  libalternatives-devel
%define libalternatives_cflags -DHAVE_LIBALTERNATIVES_H
%define libalternatives_lflags -lalternatives
%endif

%description
Common NodeJS files that allow recursive invocation of Node executable
while retaining the same codestream version.

%package -n nodejs-default
Summary:        Default version of nodejs
Group:          Development/Languages/NodeJS
Requires:       nodejs%{default_node_ver}
Requires:       nodejs-common
Provides:       nodejs = %default_node_ver
Provides:       nodejs(engine) = %default_node_ver

%description -n nodejs-default
Depends on the most current and recommended version of nodejs for
the current architecture and codestream.

%package -n npm-default
Summary:        Default version of npm
Group:          Development/Languages/NodeJS
Requires:       nodejs-default
Requires:       npm%{default_node_ver}
Provides:       npm = %default_node_ver

%description -n npm-default
Depends on the npm version associated with the current default
version of nodejs for the current architecture and codestream.

%package -n nodejs-devel-default
Summary:        Headers for default version of nodejs
Group:          Development/Languages/NodeJS
Requires:       nodejs%{default_node_ver}-devel
Requires:       npm-default
Provides:       nodejs-devel = %default_node_ver

%description -n nodejs-devel-default
Depends on the most current and up-to-date version of nodejs for
the current architecture and codestream.

%package -n corepack-default
Summary:        Default version of corepack
Group:          Development/Languages/NodeJS
Requires:       corepack%{default_node_ver}
Requires:       npm-default
Provides:       corepack = %default_node_ver

%description -n corepack-default
Depends on the corepack version associated with the current default
version of nodejs for the current architecture and codestream.

%prep

%build
cp %{S:2} .
gcc ${RPM_OPT_FLAGS} %?libalternatives_cflags -o node %{S:1} %?libalternatives_lflags

echo "Default Node version: " %{default_node_ver}

%install
install -D -m 0755 node %{buildroot}%{_bindir}/node
ln node %{buildroot}%{_bindir}/npm
ln node %{buildroot}%{_bindir}/npx
ln node %{buildroot}%{_bindir}/corepack

%files
%license LICENSE
%{_bindir}/node
%{_bindir}/npm
%{_bindir}/npx
%{_bindir}/corepack

%files -n nodejs-default

%files -n npm-default

%files -n nodejs-devel-default

%files -n corepack-default

%changelog
* Wed Nov 13 2024 Adam Majer <adam.majer@suse.de>
- Update SLFO to current LTS
* Thu May 16 2024 Adam Majer <adam.majer@suse.de>
- Update TW to 22 and set 15.7 to use it as default
* Sat Jan 27 2024 Bingwu Zhang <xtexchooser@duck.com>
- Add corepack support
* Thu Nov  9 2023 Adam Majer <adam.majer@suse.de>
- Update default TW to nodejs21
* Thu Jun 15 2023 Adam Majer <adam.majer@suse.de>
- Rework default versions and include specifics for ALP
- Default version for SLE-12 is set to be 16 - no further updates
  expected since W&S module is not supported in LTSS
- 15 SP6 uses nodejs20 as default (PED-4819)
* Tue Apr 25 2023 jsrain@suse.com
- Use NodeJS 18 as default for ALP
* Wed Apr 19 2023 Adam Majer <adam.majer@suse.de>
- Use NodeJS 20 as default for TW
* Fri Oct 21 2022 Adam Majer <adam.majer@suse.de>
- Use NodeJS 19 as default for TW
* Sun Jul 31 2022 Adam Majer <adam.majer@suse.de>
- Use NodeJS 18 as default for TW and for SLE15 SP5
* Wed Jan 12 2022 Adam Majer <adam.majer@suse.de>
- Use NodeJS 17 as default for TW
* Mon Jun 21 2021 Andreas Schneider <asn@cryptomilk.org>
- Allow building for Fedora in the OBS
* Fri Jun 18 2021 Adam Majer <adam.majer@suse.de>
- Some applications do not like warnings or notices on stderr
  as they use it for other things. So make nodejs-common quiet
  unless we have a fatal error.
* Thu Jun 10 2021 Adam Majer <adam.majer@suse.de>
- Use libalternatives on TW by default
* Mon May 31 2021 Adam Majer <adam.majer@suse.de>
- Add libalternatives support
* Thu May  6 2021 Adam Majer <adam.majer@suse.de>
- Enable 32-bit arches again on latest node for TW
- Set TW to nodejs16
- Set nodejs14 for SP3 as default and nodejs16 for SP4
* Thu Apr 29 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Provide nodejs(engine) by nodejs-common: nodejs-packaging happens
  to read the engines parameter from the json files and it's a
  nice-to-have if OBS can find out what the default nodejs engine
  to use.
* Thu Apr 15 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use older nodejs (10) for %%{arm}
* Tue Mar  9 2021 Adam Majer <adam.majer@suse.de>
- Provide nodejs and npm and nodejs-devel by the appropriate
  defaults package
* Tue Jan 19 2021 Adam Majer <adam.majer@suse.de>
- set nodejs14 as default for sle15-sp3+
- set nodejs15 as default for TW
* Tue Jun  9 2020 Adam Majer <adam.majer@suse.de>
- Add nodejs-default, npm-default and nodejs-devel-default subpackages
  to provide latest, best supported nodejs for current architecture
  and codestream.
  nodejs-default       - nodejs runtime only
  npm-default          - if you need npm + nodejs
  nodejs-devel-default - if you need npm + nodejs + compile modules
* Mon Dec 30 2019 Adam Majer <adam.majer@suse.de>
- Bump max supported version to 42 to account for automatically
  built master branch called nodejs42
* Mon Oct 28 2019 Adam Majer <adam.majer@suse.de>
- Remove extra -g from compiler command-line
* Fri Feb  1 2019 adam.majer@suse.de
- Change the shell script to regular executable
* Fri Jun 22 2018 dcassany@suse.de
- Add LICENSE text to the package
* Wed Aug  2 2017 adam.majer@suse.de
- NodeJS 8.2.0 adds support for `npx` binary. Add conditional
  support to our wrapper
- Print a helpful message if wrapper cannot find target executable
- Wrapper only executes from /usr/bin and not PATH
* Tue Jul 18 2017 adam.majer@suse.de
- Use MIT license so we don't have to ship the license text.
* Fri Jul  7 2017 adam.majer@suse.de
- Initial release.
